/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2011  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.84a                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for 78K0R - Cool it! Eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include <io78f1166_a0.h>
#include <io78f1166_a0_ext.h>

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** Assign LEDs to Ports ****************************************/

/****** Target specific configuration *******************************/

#define LED0   P14_bit.no5  /* LED1 on 78K0R - Cool it! board, active low */
#define LED1   P4_bit.no6   /* LED2 on 78K0R - Cool it! board, active low */

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PM14_bit.no5 = 0;           // Port initalization for LED1
  PM4_bit.no6  = 0;           // Port initalization for LED2
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    LED0 = 0;                 /* Switch on LED 0  */
  } else if (Index == 1) {
    LED1 = 0;                 /* Switch on LED 1  */
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    LED0 = 1;                 /* Switch off LED 0 */
  } else if (Index == 1) {
    LED1 = 1;                 /* Switch off LED 1 */
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (LED0 == 1) {
      BSP_SetLED(0);
    } else {
      BSP_ClrLED(0);
    }
  } else if (Index == 1) {
    if (LED1 == 1) {
      BSP_SetLED(1);
    } else {
      BSP_ClrLED(1);
    }
  }
}

#if 0
/*********************************************************************
*
*       LED_ClrLED0()
*/
void LED_ClrLED0(void) {
}

/*********************************************************************
*
*       LED_ToggleLED0()
*/
void LED_ToggleLED0(void) {
  if (_LED0 == 0) {
    LED_SetLED0();
  } else {
    LED_ClrLED0();
  }
}

/*********************************************************************
*
*       LED_SetLED1()
*/
void LED_SetLED1(void) {
  _LED1 = 1;                 /* Switch on LED1  */
}

/*********************************************************************
*
*       LED_ClrLED1()
*/
void LED_ClrLED1(void) {
  _LED1 = 0;                 /* Switch off LED1 */
}

/*********************************************************************
*
*       LED_ToggleLED1()
*/
void LED_ToggleLED1(void) {
  if (_LED1 == 0) {
    LED_SetLED1();
  } else {
    LED_ClrLED1();
  }
}

#endif

/****** End Of File *************************************************/
